==> amule-adunanza_3.14b3+2.2.2.orig.tar.gz: amule-adunanza-3.14b3+2.2.2/src/pixmaps/flags_xpm/CountryFlags.h <==


#ifndef COUNTRY_FLAGS_H
#define COUNTRY_FLAGS_H


#include "ad.xpm"
#include "ae.xpm"
#include "af.xpm"
#include "ag.xpm"
#include "ai.xpm"
#include "al.xpm"
#include "am.xpm"
#include "an.xpm"
#include "ao.xpm"
#include "ar.xpm"
#include "as.xpm"
#include "at.xpm"
#include "au.xpm"
#include "aw.xpm"
#include "ax.xpm"
#include "az.xpm"
#include "ba.xpm"
#include "bb.xpm"
#include "bd.xpm"
#include "be.xpm"
#include "bf.xpm"
#include "bg.xpm"
#include "bh.xpm"
#include "bi.xpm"
#include "bj.xpm"
#include "bm.xpm"
#include "bn.xpm"
#include "bo.xpm"
#include "br.xpm"
#include "bs.xpm"
#include "bt.xpm"
#include "bv.xpm"
#include "bw.xpm"
#include "by.xpm"
#include "bz.xpm"
#include "ca.xpm"
#include "catalonia.xpm"
#include "cc.xpm"
#include "cd.xpm"
#include "cf.xpm"
#include "cg.xpm"
#include "ch.xpm"
#include "ci.xpm"
#include "ck.xpm"
#include "cl.xpm"
#include "cm.xpm"
#include "cn.xpm"
#include "co.xpm"
#include "cr.xpm"
#include "cs.xpm"
#include "cu.xpm"
#include "cv.xpm"
#include "cx.xpm"
#include "cy.xpm"
#include "cz.xpm"
#include "de.xpm"
#include "dj.xpm"
#include "dk.xpm"
#include "dm.xpm"
#include "do.xpm"
#include "dz.xpm"
#include "ec.xpm"
#include "ee.xpm"
#include "eg.xpm"
#include "eh.xpm"
#include "england.xpm"
#include "er.xpm"
#include "es.xpm"
#include "et.xpm"
#include "europeanunion.xpm"
#include "fam.xpm"
#include "fi.xpm"
#include "fj.xpm"
#include "fk.xpm"
#include "fm.xpm"
#include "fo.xpm"
#include "fr.xpm"
#include "ga.xpm"
#include "gb.xpm"
#include "gd.xpm"
#include "ge.xpm"
#include "gf.xpm"
#include "gh.xpm"
#include "gi.xpm"
#include "gl.xpm"
#include "gm.xpm"
#include "gn.xpm"
#include "gp.xpm"
#include "gq.xpm"
#include "gr.xpm"
#include "gs.xpm"
#include "gt.xpm"
#include "gu.xpm"
#include "gw.xpm"
#include "gy.xpm"
#include "hk.xpm"
#include "hm.xpm"
#include "hn.xpm"
#include "hr.xpm"
#include "ht.xpm"
#include "hu.xpm"
#include "id.xpm"
#include "ie.xpm"
#include "il.xpm"
#include "in.xpm"
#include "io.xpm"
#include "iq.xpm"
#include "ir.xpm"
#include "is.xpm"
#include "it.xpm"
#include "jm.xpm"
#include "jo.xpm"
#include "jp.xpm"
#include "ke.xpm"
#include "kg.xpm"
#include "kh.xpm"
#include "ki.xpm"
#include "km.xpm"
#include "kn.xpm"
#include "kp.xpm"
#include "kr.xpm"
#include "kw.xpm"
#include "ky.xpm"
#include "kz.xpm"
#include "la.xpm"
#include "lb.xpm"
#include "lc.xpm"
#include "li.xpm"
#include "lk.xpm"
#include "lr.xpm"
#include "ls.xpm"
#include "lt.xpm"
#include "lu.xpm"
#include "lv.xpm"
#include "ly.xpm"
#include "ma.xpm"
#include "mc.xpm"
#include "md.xpm"
#include "me.xpm"
#include "mg.xpm"
#include "mh.xpm"
#include "mk.xpm"
#include "ml.xpm"
#include "mm.xpm"
#include "mn.xpm"
#include "mo.xpm"
#include "mp.xpm"
#include "mq.xpm"
#include "mr.xpm"
#include "ms.xpm"
#include "mt.xpm"
#include "mu.xpm"
#include "mv.xpm"
#include "mw.xpm"
#include "mx.xpm"
#include "my.xpm"
#include "mz.xpm"
#include "na.xpm"
#include "nc.xpm"
#include "ne.xpm"
#include "nf.xpm"
#include "ng.xpm"
#include "ni.xpm"
#include "nl.xpm"
#include "no.xpm"
#include "np.xpm"
#include "nr.xpm"
#include "nu.xpm"
#include "nz.xpm"
#include "om.xpm"
#include "pa.xpm"
#include "pe.xpm"
#include "pf.xpm"
#include "pg.xpm"
#include "ph.xpm"
#include "pk.xpm"
#include "pl.xpm"
#include "pm.xpm"
#include "pn.xpm"
#include "pr.xpm"
#include "ps.xpm"
#include "pt.xpm"
#include "pw.xpm"
#include "py.xpm"
#include "qa.xpm"
#include "re.xpm"
#include "ro.xpm"
#include "rs.xpm"
#include "ru.xpm"
#include "rw.xpm"
#include "sa.xpm"
#include "sb.xpm"
#include "sc.xpm"
#include "scotland.xpm"
#include "sd.xpm"
#include "se.xpm"
#include "sg.xpm"
#include "sh.xpm"
#include "si.xpm"
#include "sj.xpm"
#include "sk.xpm"
#include "sl.xpm"
#include "sm.xpm"
#include "sn.xpm"
#include "so.xpm"
#include "sr.xpm"
#include "st.xpm"
#include "sv.xpm"
#include "sy.xpm"
#include "sz.xpm"
#include "tc.xpm"
#include "td.xpm"
#include "tf.xpm"
#include "tg.xpm"
#include "th.xpm"
#include "tj.xpm"
#include "tk.xpm"
#include "tl.xpm"
#include "tm.xpm"
#include "tn.xpm"
#include "to.xpm"
#include "tr.xpm"
#include "tt.xpm"
#include "tv.xpm"
#include "tw.xpm"
#include "tz.xpm"
#include "ua.xpm"
#include "ug.xpm"
#include "um.xpm"
#include "unknown.xpm"
#include "us.xpm"
#include "uy.xpm"
#include "uz.xpm"
#include "va.xpm"
#include "vc.xpm"
#include "ve.xpm"
#include "vg.xpm"
#include "vi.xpm"
#include "vn.xpm"
#include "vu.xpm"
#include "wales.xpm"
#include "wf.xpm"
#include "ws.xpm"
#include "ye.xpm"
#include "yt.xpm"
#include "za.xpm"
#include "zm.xpm"
#include "zw.xpm"


struct FlagXPMCode
{
	const char **xpm;
	const char *code;
};


static struct FlagXPMCode flagXPMCodeVector[] = {
	{ad, "ad"},
	{ae, "ae"},
	{af, "af"},
	{ag, "ag"},
	{ai, "ai"},
	{al, "al"},
	{am, "am"},
	{an, "an"},
	{ao, "ao"},
	{ar, "ar"},
	{as, "as"},
	{at, "at"},
	{au, "au"},
	{aw, "aw"},
	{ax, "ax"},
	{az, "az"},
	{ba, "ba"},
	{bb, "bb"},
	{bd, "bd"},
	{be, "be"},
	{bf, "bf"},
	{bg, "bg"},
	{bh, "bh"},
	{bi, "bi"},
	{bj, "bj"},
	{bm, "bm"},
	{bn, "bn"},
	{bo, "bo"},
	{br, "br"},
	{bs, "bs"},
	{bt, "bt"},
	{bv, "bv"},
	{bw, "bw"},
	{by, "by"},
	{bz, "bz"},
	{ca, "ca"},
	{catalonia, "catalonia"},
	{cc, "cc"},
	{cd, "cd"},
	{cf, "cf"},
	{cg, "cg"},
	{ch, "ch"},
	{ci, "ci"},
	{ck, "ck"},
	{cl, "cl"},
	{cm, "cm"},
	{cn, "cn"},
	{co, "co"},
	{cr, "cr"},
	{cs, "cs"},
	{cu, "cu"},
	{cv, "cv"},
	{cx, "cx"},
	{cy, "cy"},
	{cz, "cz"},
	{de, "de"},
	{dj, "dj"},
	{dk, "dk"},
	{dm, "dm"},
	{do_, "do"},
	{dz, "dz"},
	{ec, "ec"},
	{ee, "ee"},
	{eg, "eg"},
	{eh, "eh"},
	{england, "england"},
	{er, "er"},
	{es, "es"},
	{et, "et"},
	{europeanunion, "europeanunion"},
	{fam, "fam"},
	{fi, "fi"},
	{fj, "fj"},
	{fk, "fk"},
	{fm, "fm"},
	{fo, "fo"},
	{fr, "fr"},
	{ga, "ga"},
	{gb, "gb"},
	{gd, "gd"},
	{ge, "ge"},
	{gf, "gf"},
	{gh, "gh"},
	{gi, "gi"},
	{gl, "gl"},
	{gm, "gm"},
	{gn, "gn"},
	{gp, "gp"},
	{gq, "gq"},
	{gr, "gr"},
	{gs, "gs"},
	{gt, "gt"},
	{gu, "gu"},
	{gw, "gw"},
	{gy, "gy"},
	{hk, "hk"},
	{hm, "hm"},
	{hn, "hn"},
	{hr, "hr"},
	{ht_, "ht"},
	{hu, "hu"},
	{id, "id"},
	{ie, "ie"},
	{il, "il"},
	{in, "in"},
	{io, "io"},
	{iq, "iq"},
	{ir, "ir"},
	{is, "is"},
	{it_, "it"},
	{jm, "jm"},
	{jo, "jo"},
	{jp, "jp"},
	{ke, "ke"},
	{kg, "kg"},
	{kh, "kh"},
	{ki, "ki"},
	{km, "km"},
	{kn, "kn"},
	{kp, "kp"},
	{kr, "kr"},
	{kw, "kw"},
	{ky, "ky"},
	{kz, "kz"},
	{la, "la"},
	{lb, "lb"},
	{lc, "lc"},
	{li, "li"},
	{lk, "lk"},
	{lr, "lr"},
	{ls, "ls"},
	{lt, "lt"},
	{lu, "lu"},
	{lv, "lv"},
	{ly, "ly"},
	{ma, "ma"},
	{mc, "mc"},
	{md, "md"},
	{me, "me"},
	{mg, "mg"},
	{mh, "mh"},
	{mk, "mk"},
	{ml, "ml"},
	{mm, "mm"},
	{mn, "mn"},
	{mo, "mo"},
	{mp, "mp"},
	{mq, "mq"},
	{mr, "mr"},
	{ms, "ms"},
	{mt, "mt"},
	{mu, "mu"},
	{mv, "mv"},
	{mw, "mw"},
	{mx, "mx"},
	{my, "my"},
	{mz, "mz"},
	{na, "na"},
	{nc, "nc"},
	{ne, "ne"},
	{nf, "nf"},
	{ng, "ng"},
	{ni, "ni"},
	{nl, "nl"},
	{no, "no"},
	{np, "np"},
	{nr, "nr"},
	{nu, "nu"},
	{nz, "nz"},
	{om, "om"},
	{pa, "pa"},
	{pe, "pe"},
	{pf, "pf"},
	{pg, "pg"},
	{ph, "ph"},
	{pk, "pk"},
	{pl, "pl"},
	{pm, "pm"},
	{pn, "pn"},
	{pr, "pr"},
	{ps, "ps"},
	{pt, "pt"},
	{pw, "pw"},
	{py, "py"},
	{qa, "qa"},
	{re, "re"},
	{ro, "ro"},
	{rs, "rs"},
	{ru, "ru"},
	{rw, "rw"},
	{sa, "sa"},
	{sb, "sb"},
	{sc, "sc"},
	{scotland, "scotland"},
	{sd, "sd"},
	{se, "se"},
	{sg, "sg"},
	{sh, "sh"},
	{si, "si"},
	{sj, "sj"},
	{sk, "sk"},
	{sl, "sl"},
	{sm, "sm"},
	{sn, "sn"},
	{so, "so"},
	{sr, "sr"},
	{st, "st"},
	{sv, "sv"},
	{sy, "sy"},
	{sz_, "sz"},
	{tc, "tc"},
	{td, "td"},
	{tf, "tf"},
	{tg, "tg"},
	{th, "th"},
	{tj, "tj"},
	{tk, "tk"},
	{tl, "tl"},
	{tm, "tm"},
	{tn, "tn"},
	{to, "to"},
	{tr, "tr"},
	{tt, "tt"},
	{tv, "tv"},
	{tw, "tw"},
	{tz, "tz"},
	{ua, "ua"},
	{ug, "ug"},
	{um, "um"},
	{unknown, "unknown"},
	{us, "us"},
	{uy, "uy"},
	{uz, "uz"},
	{va, "va"},
	{vc, "vc"},
	{ve, "ve"},
	{vg, "vg"},
	{vi, "vi"},
	{vn, "vn"},
	{vu, "vu"},
	{wales, "wales"},
	{wf, "wf"},
	{ws, "ws"},
	{ye, "ye"},
	{yt, "yt"},
	{za, "za"},
	{zm, "zm"},
	{zw, "zw"},
};


static const int FLAGS_XPM_SIZE = (sizeof flagXPMCodeVector) / (sizeof flagXPMCodeVector[0]);


#endif // COUNTRY_FLAGS_H

==> amule-adunanza_2012.1+2.3.1~dfsg1.orig.tar.gz: amule-adunanza-2012.1+2.3.1~dfsg1.orig/src/pixmaps/flags_xpm/CountryFlags.h <==


#ifndef COUNTRY_FLAGS_H
#define COUNTRY_FLAGS_H

namespace flags {

#include "ad.xpm"
#include "ae.xpm"
#include "af.xpm"
#include "ag.xpm"
#include "ai.xpm"
#include "al.xpm"
#include "am.xpm"
#include "an.xpm"
#include "ao.xpm"
#include "ar.xpm"
#include "as.xpm"
#include "at.xpm"
#include "au.xpm"
#include "aw.xpm"
#include "ax.xpm"
#include "az.xpm"
#include "ba.xpm"
#include "bb.xpm"
#include "bd.xpm"
#include "be.xpm"
#include "bf.xpm"
#include "bg.xpm"
#include "bh.xpm"
#include "bi.xpm"
#include "bj.xpm"
#include "bm.xpm"
#include "bn.xpm"
#include "bo.xpm"
#include "br.xpm"
#include "bs.xpm"
#include "bt.xpm"
#include "bv.xpm"
#include "bw.xpm"
#include "by.xpm"
#include "bz.xpm"
#include "ca.xpm"
#include "cc.xpm"
#include "cd.xpm"
#include "cf.xpm"
#include "cg.xpm"
#include "ch.xpm"
#include "ci.xpm"
#include "ck.xpm"
#include "cl.xpm"
#include "cm.xpm"
#include "cn.xpm"
#include "co.xpm"
#include "cr.xpm"
#include "cu.xpm"
#include "cv.xpm"
#include "cx.xpm"
#include "cy.xpm"
#include "cz.xpm"
#include "de.xpm"
#include "dj.xpm"
#include "dk.xpm"
#include "dm.xpm"
#include "do.xpm"
#include "dz.xpm"
#include "ec.xpm"
#include "ee.xpm"
#include "eg.xpm"
#include "eh.xpm"
#include "er.xpm"
#include "es.xpm"
#include "et.xpm"
#include "eu.xpm"
#include "fastweb.xpm"
#include "fi.xpm"
#include "fj.xpm"
#include "fk.xpm"
#include "fm.xpm"
#include "fo.xpm"
#include "fr.xpm"
#include "ga.xpm"
#include "gb.xpm"
#include "gd.xpm"
#include "ge.xpm"
#include "gf.xpm"
#include "gh.xpm"
#include "gi.xpm"
#include "gl.xpm"
#include "gm.xpm"
#include "gn.xpm"
#include "gp.xpm"
#include "gq.xpm"
#include "gr.xpm"
#include "gs.xpm"
#include "gt.xpm"
#include "gu.xpm"
#include "gw.xpm"
#include "gy.xpm"
#include "hk.xpm"
#include "hm.xpm"
#include "hn.xpm"
#include "hr.xpm"
#include "ht.xpm"
#include "hu.xpm"
#include "id.xpm"
#include "ie.xpm"
#include "il.xpm"
#include "in.xpm"
#include "io.xpm"
#include "iq.xpm"
#include "ir.xpm"
#include "is.xpm"
#include "it.xpm"
#include "jm.xpm"
#include "jo.xpm"
#include "jp.xpm"
#include "ke.xpm"
#include "kg.xpm"
#include "kh.xpm"
#include "ki.xpm"
#include "km.xpm"
#include "kn.xpm"
#include "kp.xpm"
#include "kr.xpm"
#include "kw.xpm"
#include "ky.xpm"
#include "kz.xpm"
#include "la.xpm"
#include "lb.xpm"
#include "lc.xpm"
#include "li.xpm"
#include "lk.xpm"
#include "lr.xpm"
#include "ls.xpm"
#include "lt.xpm"
#include "lu.xpm"
#include "lv.xpm"
#include "ly.xpm"
#include "ma.xpm"
#include "mc.xpm"
#include "md.xpm"
#include "me.xpm"
#include "mg.xpm"
#include "mh.xpm"
#include "mk.xpm"
#include "ml.xpm"
#include "mm.xpm"
#include "mn.xpm"
#include "mo.xpm"
#include "mp.xpm"
#include "mq.xpm"
#include "mr.xpm"
#include "ms.xpm"
#include "mt.xpm"
#include "mu.xpm"
#include "mv.xpm"
#include "mw.xpm"
#include "mx.xpm"
#include "my.xpm"
#include "mz.xpm"
#include "na.xpm"
#include "nc.xpm"
#include "ne.xpm"
#include "nf.xpm"
#include "ng.xpm"
#include "ni.xpm"
#include "nl.xpm"
#include "no.xpm"
#include "np.xpm"
#include "nr.xpm"
#include "nu.xpm"
#include "nz.xpm"
#include "om.xpm"
#include "pa.xpm"
#include "pe.xpm"
#include "pf.xpm"
#include "pg.xpm"
#include "ph.xpm"
#include "pk.xpm"
#include "pl.xpm"
#include "pm.xpm"
#include "pn.xpm"
#include "pr.xpm"
#include "ps.xpm"
#include "pt.xpm"
#include "pw.xpm"
#include "py.xpm"
#include "qa.xpm"
#include "re.xpm"
#include "ro.xpm"
#include "rs.xpm"
#include "ru.xpm"
#include "rw.xpm"
#include "sa.xpm"
#include "sb.xpm"
#include "sc.xpm"
#include "sd.xpm"
#include "se.xpm"
#include "sg.xpm"
#include "sh.xpm"
#include "si.xpm"
#include "sj.xpm"
#include "sk.xpm"
#include "sl.xpm"
#include "sm.xpm"
#include "sn.xpm"
#include "so.xpm"
#include "sr.xpm"
#include "st.xpm"
#include "sv.xpm"
#include "sy.xpm"
#include "sz.xpm"
#include "tc.xpm"
#include "td.xpm"
#include "tf.xpm"
#include "tg.xpm"
#include "th.xpm"
#include "tj.xpm"
#include "tk.xpm"
#include "tl.xpm"
#include "tm.xpm"
#include "tn.xpm"
#include "to.xpm"
#include "tr.xpm"
#include "tt.xpm"
#include "tv.xpm"
#include "tw.xpm"
#include "tz.xpm"
#include "ua.xpm"
#include "ug.xpm"
#include "um.xpm"
#include "unknown.xpm"
#include "us.xpm"
#include "uy.xpm"
#include "uz.xpm"
#include "va.xpm"
#include "vc.xpm"
#include "ve.xpm"
#include "vg.xpm"
#include "vi.xpm"
#include "vn.xpm"
#include "vu.xpm"
#include "wf.xpm"
#include "ws.xpm"
#include "ye.xpm"
#include "yt.xpm"
#include "za.xpm"
#include "zm.xpm"
#include "zw.xpm"


struct FlagXPMCode
{
	const char **xpm;
	const char *code;
};


static struct FlagXPMCode flagXPMCodeVector[] = {
	{ad, "ad"},
	{ae, "ae"},
	{af, "af"},
	{ag, "ag"},
	{ai, "ai"},
	{al, "al"},
	{am, "am"},
	{an, "an"},
	{ao, "ao"},
	{ar, "ar"},
	{as, "as"},
	{at, "at"},
	{au, "au"},
	{aw, "aw"},
	{ax, "ax"},
	{az, "az"},
	{ba, "ba"},
	{bb, "bb"},
	{bd, "bd"},
	{be, "be"},
	{bf, "bf"},
	{bg, "bg"},
	{bh, "bh"},
	{bi, "bi"},
	{bj, "bj"},
	{bm, "bm"},
	{bn, "bn"},
	{bo, "bo"},
	{br, "br"},
	{bs, "bs"},
	{bt, "bt"},
	{bv, "bv"},
	{bw, "bw"},
	{by, "by"},
	{bz, "bz"},
	{ca, "ca"},
	{cc, "cc"},
	{cd, "cd"},
	{cf, "cf"},
	{cg, "cg"},
	{ch, "ch"},
	{ci, "ci"},
	{ck, "ck"},
	{cl, "cl"},
	{cm, "cm"},
	{cn, "cn"},
	{co, "co"},
	{cr, "cr"},
	{cu, "cu"},
	{cv, "cv"},
	{cx, "cx"},
	{cy, "cy"},
	{cz, "cz"},
	{de, "de"},
	{dj, "dj"},
	{dk, "dk"},
	{dm, "dm"},
	{do_, "do"},
	{dz, "dz"},
	{ec, "ec"},
	{ee, "ee"},
	{eg, "eg"},
	{eh, "eh"},
	{er, "er"},
	{es, "es"},
	{et, "et"},
	{eu, "eu"},
	{fastweb, "FW"},
	{fi, "fi"},
	{fj, "fj"},
	{fk, "fk"},
	{fm, "fm"},
	{fo, "fo"},
	{fr, "fr"},
	{ga, "ga"},
	{gb, "gb"},
	{gd, "gd"},
	{ge, "ge"},
	{gf, "gf"},
	{gh, "gh"},
	{gi, "gi"},
	{gl, "gl"},
	{gm, "gm"},
	{gn, "gn"},
	{gp, "gp"},
	{gq, "gq"},
	{gr, "gr"},
	{gs, "gs"},
	{gt, "gt"},
	{gu, "gu"},
	{gw, "gw"},
	{gy, "gy"},
	{hk, "hk"},
	{hm, "hm"},
	{hn, "hn"},
	{hr, "hr"},
	{ht, "ht"},
	{hu, "hu"},
	{id, "id"},
	{ie, "ie"},
	{il, "il"},
	{in, "in"},
	{io, "io"},
	{iq, "iq"},
	{ir, "ir"},
	{is, "is"},
	{it, "it"},
	{jm, "jm"},
	{jo, "jo"},
	{jp, "jp"},
	{ke, "ke"},
	{kg, "kg"},
	{kh, "kh"},
	{ki, "ki"},
	{km, "km"},
	{kn, "kn"},
	{kp, "kp"},
	{kr, "kr"},
	{kw, "kw"},
	{ky, "ky"},
	{kz, "kz"},
	{la, "la"},
	{lb, "lb"},
	{lc, "lc"},
	{li, "li"},
	{lk, "lk"},
	{lr, "lr"},
	{ls, "ls"},
	{lt, "lt"},
	{lu, "lu"},
	{lv, "lv"},
	{ly, "ly"},
	{ma, "ma"},
	{mc, "mc"},
	{md, "md"},
	{me, "me"},
	{mg, "mg"},
	{mh, "mh"},
	{mk, "mk"},
	{ml, "ml"},
	{mm, "mm"},
	{mn, "mn"},
	{mo, "mo"},
	{mp, "mp"},
	{mq, "mq"},
	{mr, "mr"},
	{ms, "ms"},
	{mt, "mt"},
	{mu, "mu"},
	{mv, "mv"},
	{mw, "mw"},
	{mx, "mx"},
	{my, "my"},
	{mz, "mz"},
	{na, "na"},
	{nc, "nc"},
	{ne, "ne"},
	{nf, "nf"},
	{ng, "ng"},
	{ni, "ni"},
	{nl, "nl"},
	{no, "no"},
	{np, "np"},
	{nr, "nr"},
	{nu, "nu"},
	{nz, "nz"},
	{om, "om"},
	{pa, "pa"},
	{pe, "pe"},
	{pf, "pf"},
	{pg, "pg"},
	{ph, "ph"},
	{pk, "pk"},
	{pl, "pl"},
	{pm, "pm"},
	{pn, "pn"},
	{pr, "pr"},
	{ps, "ps"},
	{pt, "pt"},
	{pw, "pw"},
	{py, "py"},
	{qa, "qa"},
	{re, "re"},
	{ro, "ro"},
	{rs, "rs"},
	{ru, "ru"},
	{rw, "rw"},
	{sa, "sa"},
	{sb, "sb"},
	{sc, "sc"},
	{sd, "sd"},
	{se, "se"},
	{sg, "sg"},
	{sh, "sh"},
	{si, "si"},
	{sj, "sj"},
	{sk, "sk"},
	{sl, "sl"},
	{sm, "sm"},
	{sn, "sn"},
	{so, "so"},
	{sr, "sr"},
	{st, "st"},
	{sv, "sv"},
	{sy, "sy"},
	{sz, "sz"},
	{tc, "tc"},
	{td, "td"},
	{tf, "tf"},
	{tg, "tg"},
	{th, "th"},
	{tj, "tj"},
	{tk, "tk"},
	{tl, "tl"},
	{tm, "tm"},
	{tn, "tn"},
	{to, "to"},
	{tr, "tr"},
	{tt, "tt"},
	{tv, "tv"},
	{tw, "tw"},
	{tz, "tz"},
	{ua, "ua"},
	{ug, "ug"},
	{um, "um"},
	{unknown, "unknown"},
	{us, "us"},
	{uy, "uy"},
	{uz, "uz"},
	{va, "va"},
	{vc, "vc"},
	{ve, "ve"},
	{vg, "vg"},
	{vi, "vi"},
	{vn, "vn"},
	{vu, "vu"},
	{wf, "wf"},
	{ws, "ws"},
	{ye, "ye"},
	{yt, "yt"},
	{za, "za"},
	{zm, "zm"},
	{zw, "zw"},
};


static const int FLAGS_XPM_SIZE = (sizeof flagXPMCodeVector) / (sizeof flagXPMCodeVector[0]);


}	// namespace flags
#endif // COUNTRY_FLAGS_H
